pub struct ClusterPeerFetchRequest {
pub owner: ClusterNodeId,
pub key: String,
pub generation: Option<ClusterGeneration>,
}Fields
owner: ClusterNodeIdOwner member expected to serve this request.
key: StringLogical cache key requested from the owner.
generation: Option<ClusterGeneration>Optional owner generation observed by the caller.
Implementations
Sourceimpl ClusterPeerFetchRequest
impl ClusterPeerFetchRequest
Sourcepub fn new(owner: impl Into<ClusterNodeId>, key: impl Into<String>) -> Self
pub fn new(owner: impl Into<ClusterNodeId>, key: impl Into<String>) -> Self
Create a new peer-fetch request.
Sourcepub fn generation(self, generation: ClusterGeneration) -> Self
pub fn generation(self, generation: ClusterGeneration) -> Self
Attach the owner generation observed by the caller.
Sourcepub fn has_generation(&self) -> bool
pub fn has_generation(&self) -> bool
Return whether this request carries an observed owner generation.
Sourcepub fn matches_generation(&self, current: ClusterGeneration) -> bool
pub fn matches_generation(&self, current: ClusterGeneration) -> bool
Return whether this request can be served by current owner generation.
Sourcepub fn generation_mismatch(
&self,
current: ClusterGeneration,
) -> Option<ClusterPeerFetchGenerationMismatch>
pub fn generation_mismatch( &self, current: ClusterGeneration, ) -> Option<ClusterPeerFetchGenerationMismatch>
Return mismatch details when the observed owner generation is stale.