pub struct TombstoneTracker { /* private fields */ }Expand description
Small deterministic tombstone budget tracker used by the 0.41 gate tests.
Implementations
Sourceimpl TombstoneTracker
impl TombstoneTracker
Sourcepub fn new(budget: TombstoneBudget) -> Self
pub fn new(budget: TombstoneBudget) -> Self
Create an empty tracker.
Sourcepub fn admit(
&mut self,
key: impl Into<String>,
version: u64,
approx_bytes: u64,
gc_eligible_after: Option<ClusterEpoch>,
) -> TombstoneAdmission
pub fn admit( &mut self, key: impl Into<String>, version: u64, approx_bytes: u64, gc_eligible_after: Option<ClusterEpoch>, ) -> TombstoneAdmission
Admit or replace a tombstone and enforce the budget.
Sourcepub fn confirm_repair(&mut self, key: &str, epoch: ClusterEpoch)
pub fn confirm_repair(&mut self, key: &str, epoch: ClusterEpoch)
Mark a tombstone as repair-confirmed and eligible after epoch.
Sourcepub fn gc_eligible_after(&self, key: &str) -> Option<ClusterEpoch>
pub fn gc_eligible_after(&self, key: &str) -> Option<ClusterEpoch>
Return the epoch after which a tombstone may be GC’d, if repair was confirmed.
Sourcepub fn forget(&mut self, key: &str) -> bool
pub fn forget(&mut self, key: &str) -> bool
Forget a tombstone after the durable record has been reclaimed.
Sourcepub fn repair_debt(&self) -> bool
pub fn repair_debt(&self) -> bool
Return whether the tracker is in repair debt.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Return whether the key is retained.